@@ -60,12 +60,17 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccount;
+import com.openexchange.oauth.OAuthExceptionCodes;
+import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthServiceMetaData;
+import com.openexchange.oauth.scope.OXScope;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 import com.openexchange.subscribe.SubscribeService;
 import com.openexchange.subscribe.Subscription;
+import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.SubscriptionSource;
 import com.openexchange.subscribe.mslive.internal.ContactParser;
 
@@ -82,7 +87,7 @@ public class ContactsMSLiveSubscribeService extends AbstractMSLiveSubscribeServi
 
     /**
      * Initializes a new {@link ContactsMSLiveSubscribeService}.
-     * 
+     *
      * @param oAuthServiceMetaData
      * @param services
      */
@@ -103,23 +108,42 @@ public class ContactsMSLiveSubscribeService extends AbstractMSLiveSubscribeServi
 
     /*
      * (non-Javadoc)
+     *
      * @see com.openexchange.subscribe.SubscribeService#getContent(com.openexchange.subscribe.Subscription)
      */
     @Override
     public Collection<?> getContent(Subscription subscription) throws OXException {
-        final Session session = subscription.getSession();
-        final OAuthAccount oauthAccount = MSLiveApiClient.getDefaultOAuthAccount(session);
-        final String accessToken = MSLiveApiClient.getAccessToken(oauthAccount, session);
-        final JSONObject contacts = fetchData(accessToken);
-        final ContactParser parser = new ContactParser();
-        return parser.parse(contacts);
+        Session session = subscription.getSession();
+
+        // Load associated OAuth account
+        OAuthAccount oauthAccount;
+        {
+            Object accountId = subscription.getConfiguration().get("account");
+            if (null == accountId) {
+                oauthAccount = MSLiveApiClient.getDefaultOAuthAccount(session);
+            } else {
+                int iAccountId;
+                if (accountId instanceof Integer) {
+                    iAccountId = ((Integer) accountId).intValue();
+                } else {
+                    iAccountId = Integer.parseInt(accountId.toString());
+                }
+                OAuthService service = services.getService(OAuthService.class);
+                oauthAccount = service.getAccount(iAccountId, session, session.getUserId(), session.getContextId());
+            }
+        }
+
+        String accessToken = MSLiveApiClient.getAccessToken(oauthAccount, session);
+        JSONObject contacts = fetchData(accessToken);
+        return ContactParser.getInstance().parse(contacts);
     }
 
     /**
      * @param accessToken
      * @return
+     * @throws OXException
      */
-    private JSONObject fetchData(final String accessToken) {
+    private JSONObject fetchData(final String accessToken) throws OXException {
         JSONObject wholeResponse = new JSONObject();
         try {
             final String protectedUrl = "https://apis.live.net/v5.0/me/contacts?access_token=" + URLEncoder.encode(accessToken, "UTF-8");
@@ -133,12 +157,24 @@ public class ContactsMSLiveSubscribeService extends AbstractMSLiveSubscribeServi
             String response = getMethod.getResponseBodyAsString();
             wholeResponse = new JSONObject(response);
 
+            if (wholeResponse.hasAndNotNull("error")) {
+                JSONObject error = wholeResponse.getJSONObject("error");
+                String code = error.getString("code");
+                if (code.equals("request_token_unauthorized")) {
+                    throw OAuthExceptionCodes.NO_SCOPE_PERMISSION.create(KnownApi.MS_LIVE_CONNECT.getShortName(), OXScope.contacts_ro.getDisplayName());
+                }
+                throw SubscriptionErrorMessage.UNEXPECTED_ERROR.create(error.getString("message"));
+            }
+
         } catch (final HttpException e) {
             LOG.error("", e);
+            throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e, e.getMessage());
         } catch (final IOException e) {
             LOG.error("", e);
+            throw SubscriptionErrorMessage.IO_ERROR.create(e, e.getMessage());
         } catch (final JSONException e) {
             LOG.error("", e);
+            throw SubscriptionErrorMessage.ParseException.create(e, e.getMessage());
         }
         return wholeResponse;
     }
